pygeodesy.auxilats.auxDST

Package pygeodesy :: Package auxilats :: Module auxDST |
[frames] | no frames]

# Module auxDST

Discrete Sine Transforms (AuxDST) in Python, transcoded from Karney's C++ class DST in GeographicLib version 2.2+.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Note: Class AuxDST requires numpy to be installed, version 1.16 or newer.

Version: 25.05.12

Classes
| AuxDST Discrete Sine Transforms (DST) for Auxiliary latitudes.